@@ -1,18 +1,13 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
-
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
-
 DOCUMENTATION = r"""
 ---
 module: configuration_template_info
-short_description: Information module for Configuration Template
+short_description: Information module for Configuration Template Info
 description:
-- Get all Configuration Template.
-- Get Configuration Template by id.
-- Details of the template by its id.
-- List the templates available.
+  - This module represents an alias of the module configuration_template_v1_info
 version_added: '3.1.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -23,81 +18,79 @@ options:
     type: dict
   projectId:
     description:
-    - ProjectId query parameter. Filter template(s) based on project UUID.
+      - ProjectId query parameter. Filter template(s) based on project UUID.
     type: str
   softwareType:
     description:
-    - SoftwareType query parameter. Filter template(s) based software type.
+      - SoftwareType query parameter. Filter template(s) based software type.
     type: str
   softwareVersion:
     description:
-    - SoftwareVersion query parameter. Filter template(s) based softwareVersion.
+      - SoftwareVersion query parameter. Filter template(s) based softwareVersion.
     type: str
   productFamily:
     description:
-    - ProductFamily query parameter. Filter template(s) based on device family.
+      - ProductFamily query parameter. Filter template(s) based on device family.
     type: str
   productSeries:
     description:
-    - ProductSeries query parameter. Filter template(s) based on device series.
+      - ProductSeries query parameter. Filter template(s) based on device series.
     type: str
   productType:
     description:
-    - ProductType query parameter. Filter template(s) based on device type.
+      - ProductType query parameter. Filter template(s) based on device type.
     type: str
   filterConflictingTemplates:
     description:
-    - FilterConflictingTemplates query parameter. Filter template(s) based on confliting templates.
+      - FilterConflictingTemplates query parameter. Filter template(s) based on confliting
+        templates.
     type: bool
   tags:
     description:
-    - Tags query parameter. Filter template(s) based on tags.
+      - Tags query parameter. Filter template(s) based on tags.
     elements: str
     type: list
   projectNames:
     description:
-    - ProjectNames query parameter. Filter template(s) based on project names.
+      - ProjectNames query parameter. Filter template(s) based on project names.
     elements: str
     type: list
   unCommitted:
     description:
-    - UnCommitted query parameter. Filter template(s) based on template commited or not.
+      - UnCommitted query parameter. Filter template(s) based on template commited
+        or not.
     type: bool
   sortOrder:
     description:
-    - SortOrder query parameter. Sort Order Ascending (asc) or Descending (des).
+      - SortOrder query parameter. Sort Order Ascending (asc) or Descending (des).
     type: str
   templateId:
     description:
-    - TemplateId path parameter. TemplateId(UUID) to get details of the template.
+      - TemplateId path parameter. TemplateId(UUID) to get details of the template.
     type: str
   latestVersion:
     description:
-    - LatestVersion query parameter. LatestVersion flag to get the latest versioned template.
+      - LatestVersion query parameter. LatestVersion flag to get the latest versioned
+        template.
     type: bool
 requirements:
-- dnacentersdk >= 2.5.0
-- python >= 3.5
+  - dnacentersdk >= 2.4.9
+  - python >= 3.5
 seealso:
-- name: Cisco DNA Center documentation for Configuration Templates GetsDetailsOfAGivenTemplate
-  description: Complete reference of the GetsDetailsOfAGivenTemplate API.
-  link: https://developer.cisco.com/docs/dna-center/#!gets-details-of-a-given-template
-- name: Cisco DNA Center documentation for Configuration Templates GetsTheTemplatesAvailable
-  description: Complete reference of the GetsTheTemplatesAvailable API.
-  link: https://developer.cisco.com/docs/dna-center/#!gets-the-templates-available
+  - name: Cisco DNA Center documentation for Configuration Templates GetsDetailsOfAGivenTemplateV1
+    description: Complete reference of the GetsDetailsOfAGivenTemplateV1 API.
+    link: https://developer.cisco.com/docs/dna-center/#!gets-details-of-a-given-template
+  - name: Cisco DNA Center documentation for Configuration Templates GetsTheTemplatesAvailableV1
+    description: Complete reference of the GetsTheTemplatesAvailableV1 API.
+    link: https://developer.cisco.com/docs/dna-center/#!gets-the-templates-available
 notes:
-  - SDK Method used are
-    configuration_templates.ConfigurationTemplates.get_template_details,
-    configuration_templates.ConfigurationTemplates.gets_the_templates_available,
-
-  - Paths used are
-    get /dna/intent/api/v1/template-programmer/template,
-    get /dna/intent/api/v1/template-programmer/template/{templateId},
-
+  - SDK Method used are configuration_templates.ConfigurationTemplates.get_template_details,
+    configuration_templates.ConfigurationTemplates.gets_the_templates_available_v1,
+  - Paths used are get /dna/intent/api/v1/template-programmer/template, get /dna/intent/api/v1/template-programmer/template/{templateId},
+  - It should be noted that this module is an alias of configuration_template_v1_info
 """
-
 EXAMPLES = r"""
-- name: Get all Configuration Template
+- name: Get all Configuration Template Info
   cisco.dnac.configuration_template_info:
     dnac_host: "{{dnac_host}}"
     dnac_username: "{{dnac_username}}"
@@ -113,14 +106,13 @@ EXAMPLES = r"""
     productFamily: string
     productSeries: string
     productType: string
-    filterConflictingTemplates: True
+    filterConflictingTemplates: true
     tags: []
     projectNames: []
-    unCommitted: True
+    unCommitted: true
     sortOrder: string
   register: result
-
-- name: Get Configuration Template by id
+- name: Get Configuration Template Info by id
   cisco.dnac.configuration_template_info:
     dnac_host: "{{dnac_host}}"
     dnac_username: "{{dnac_username}}"
@@ -130,12 +122,10 @@ EXAMPLES = r"""
     dnac_version: "{{dnac_version}}"
     dnac_debug: "{{dnac_debug}}"
     headers: "{{my_headers | from_json}}"
-    latestVersion: True
+    latestVersion: true
     templateId: string
   register: result
-
 """
-
 RETURN = r"""
 dnac_response:
   description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
@@ -341,12 +331,8 @@ dnac_response:
         }
       ],
       "validationErrors": {
-        "rollbackTemplateErrors": [
-          {}
-        ],
-        "templateErrors": [
-          {}
-        ],
+        "rollbackTemplateErrors": {},
+        "templateErrors": {},
         "templateId": "string",
         "templateVersion": "string"
       },
