@@ -10,23 +10,25 @@ based on the configuration.
 """
 from __future__ import absolute_import, division, print_function
 
+
 __metaclass__ = type
 
 import re
+
 from copy import deepcopy
+
 from ansible.module_utils.six import iteritems
-from ansible_collections.ansible.netcommon.plugins.module_utils.network.common import (
-    utils,
+from ansible_collections.ansible.netcommon.plugins.module_utils.network.common import utils
+from ansible_collections.ansible.netcommon.plugins.module_utils.network.common.rm_base.network_template import (
+    NetworkTemplate,
 )
+
 from ansible_collections.cisco.ios.plugins.module_utils.network.ios.argspec.ospfv3.ospfv3 import (
     Ospfv3Args,
 )
 from ansible_collections.cisco.ios.plugins.module_utils.network.ios.rm_templates.ospfv3 import (
     Ospfv3Template,
 )
-from ansible_collections.ansible.netcommon.plugins.module_utils.network.common.network_template import (
-    NetworkTemplate,
-)
 
 
 class Ospfv3Facts(object):
@@ -56,26 +58,18 @@ class Ospfv3Facts(object):
                     capdict = temp
                     if "address-family" in line:
                         capdict.update({"id": temp_pid})
-                    if (
-                        "manet" in line
-                        and "pid" not in shared
-                        and shared.get("unicast")
-                    ):
+                    if "manet" in line and "pid" not in shared and shared.get("unicast"):
                         del shared["unicast"]
 
                     if "router ospfv3" in line:
                         temp_pid = None
                     if parser.get("shared"):
                         shared = capdict
-                    if not temp_pid and (
-                        shared.get("pid") or shared.get("id")
-                    ):
+                    if not temp_pid and (shared.get("pid") or shared.get("id")):
                         temp_pid = shared.get("pid") or shared.get("id")
                     vals = utils.dict_merge(capdict, shared)
                     try:
-                        res = net_template_obj._deepformat(
-                            deepcopy(parser["result"]), vals
-                        )
+                        res = net_template_obj._deepformat(deepcopy(parser["result"]), vals)
                     except Exception:
                         continue
                     result = utils.dict_merge(result, res)
@@ -141,16 +135,12 @@ class Ospfv3Facts(object):
         for key, sortv in [("processes", "process_id")]:
             if key in current and current[key]:
                 current[key] = current[key].values()
-                current[key] = sorted(
-                    current[key], key=lambda k, sk=sortv: k[sk]
-                )
+                current[key] = sorted(current[key], key=lambda k, sk=sortv: k[sk])
 
         for process in current.get("processes", []):
             if "areas" in process:
                 process["areas"] = list(process["areas"].values())
-                process["areas"] = sorted(
-                    process["areas"], key=lambda k, sk="area_id": k[sk]
-                )
+                process["areas"] = sorted(process["areas"], key=lambda k, sk="area_id": k[sk])
                 for area in process["areas"]:
                     if "filters" in area:
                         area["filters"].sort()
@@ -158,9 +148,7 @@ class Ospfv3Facts(object):
                 for each in process["address_family"]:
                     if "areas" in each:
                         each["areas"] = list(each["areas"].values())
-                        each["areas"] = sorted(
-                            each["areas"], key=lambda k, sk="area_id": k[sk]
-                        )
+                        each["areas"] = sorted(each["areas"], key=lambda k, sk="area_id": k[sk])
                         for area in each["areas"]:
                             if "filters" in area:
                                 area["filters"].sort()
@@ -170,7 +158,9 @@ class Ospfv3Facts(object):
         facts = {}
         if current:
             params = ospfv3_parser.validate_config(
-                self.argument_spec, {"config": ipv4}, redact=True
+                self.argument_spec,
+                {"config": ipv4},
+                redact=True,
             )
             params = utils.remove_empties(params)
 
