@@ -5,35 +5,33 @@
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 DOCUMENTATION = r"""
----
 module: mnt_session_active_list_info
-short_description: Information module for Mnt Session Active List
+short_description: Information module for MNT Session Active List
 description:
-- Get all Mnt Session Active List.
+  - Get all MNT Session Active List.
 version_added: '1.0.0'
 extends_documentation_fragment:
   - cisco.ise.module_info
 author: Rafael Campos (@racampos)
 options: {}
 requirements:
-- ciscoisesdk >= 1.1.0
-- python >= 3.5
-seealso:
-# Reference by Internet resource
-- name: Mnt Session Active List reference
-  description: Complete reference of the Mnt Session Active List object model.
-  link: https://ciscoisesdk.readthedocs.io/en/latest/api/api.html#v3-0-0-summary
+  - ciscoisesdk >= 2.2.3
+  - python >= 3.5
+notes:
+  - SDK Method used are
+    misc.Misc.get_active_list,
+  - Paths used are
+    get /Session/ActiveList,
 """
 
 EXAMPLES = r"""
-- name: Get all Mnt Session Active List
+- name: Get all MNT Session Active List
   cisco.ise.mnt_session_active_list_info:
     ise_hostname: "{{ise_hostname}}"
     ise_username: "{{ise_username}}"
     ise_password: "{{ise_password}}"
     ise_verify: "{{ise_verify}}"
   register: result
-
 """
 
 RETURN = r"""
