@@ -8,52 +8,56 @@
 # SPDX-License-Identifier: GPL-3.0-or-later
 
 from __future__ import absolute_import, division, print_function
+
+
 __metaclass__ = type
 
 
-DOCUMENTATION = r'''
----
+DOCUMENTATION = r"""
 module: x509_certificate_pipe
 short_description: Generate and/or check OpenSSL certificates
 version_added: 1.3.0
 description:
-    - It implements a notion of provider (one of V(selfsigned), V(ownca), V(entrust))
-      for your certificate.
+  - It implements a notion of provider (one of V(selfsigned), V(ownca), V(entrust)) for your certificate.
 author:
-    - Yanis Guenane (@Spredzy)
-    - Markus Teufelberger (@MarkusTeufelberger)
-    - Felix Fontein (@felixfontein)
+  - Yanis Guenane (@Spredzy)
+  - Markus Teufelberger (@MarkusTeufelberger)
+  - Felix Fontein (@felixfontein)
 extends_documentation_fragment:
-    - community.crypto.attributes
-    - community.crypto.module_certificate
-    - community.crypto.module_certificate.backend_entrust_documentation
-    - community.crypto.module_certificate.backend_ownca_documentation
-    - community.crypto.module_certificate.backend_selfsigned_documentation
+  - community.crypto.attributes
+  - community.crypto.module_certificate
+  - community.crypto.module_certificate.backend_entrust_documentation
+  - community.crypto.module_certificate.backend_ownca_documentation
+  - community.crypto.module_certificate.backend_selfsigned_documentation
 attributes:
-    check_mode:
-        support: full
-    diff_mode:
-        support: full
+  check_mode:
+    support: full
+    details:
+      - Currently in check mode, private keys will not be (re-)generated, only the changed status is set. This will change
+        in community.crypto 3.0.0.
+      - From community.crypto 3.0.0 on, the module will ignore check mode and always behave as if check mode is not active.
+        If you think this breaks your use-case of this module, please create an issue in the community.crypto repository.
 options:
-    provider:
-        description:
-            - Name of the provider to use to generate/retrieve the OpenSSL certificate.
-            - "The V(entrust) provider requires credentials for the
-               L(Entrust Certificate Services,https://www.entrustdatacard.com/products/categories/ssl-certificates) (ECS) API."
-        type: str
-        choices: [ entrust, ownca, selfsigned ]
-        required: true
+  provider:
+    description:
+      - Name of the provider to use to generate/retrieve the OpenSSL certificate.
+      - The V(entrust) provider requires credentials for the L(Entrust Certificate Services,
+        https://www.entrustdatacard.com/products/categories/ssl-certificates) (ECS) API.
+    type: str
+    choices: [entrust, ownca, selfsigned]
+    required: true
 
-    content:
-        description:
-            - The existing certificate.
-        type: str
+  content:
+    description:
+      - The existing certificate.
+    type: str
 
 seealso:
-    - module: community.crypto.x509_certificate
-'''
+  - module: community.crypto.x509_certificate
+"""
 
-EXAMPLES = r'''
+EXAMPLES = r"""
+---
 - name: Generate a Self Signed OpenSSL certificate
   community.crypto.x509_certificate_pipe:
     provider: selfsigned
@@ -113,88 +117,99 @@ EXAMPLES = r'''
     dest: /etc/ssl/csr/www.ansible.com.crt
     content: "{{ result.certificate }}"
   when: result is changed
-'''
+"""
 
-RETURN = r'''
+RETURN = r"""
 certificate:
-    description: The (current or generated) certificate's content.
-    returned: changed or success
-    type: str
-'''
+  description: The (current or generated) certificate's content.
+  returned: changed or success
+  type: str
+"""
 
 
 from ansible.module_utils.common.text.converters import to_native
-
+from ansible_collections.community.crypto.plugins.module_utils.crypto.basic import (
+    OpenSSLObjectError,
+)
 from ansible_collections.community.crypto.plugins.module_utils.crypto.module_backends.certificate import (
+    get_certificate_argument_spec,
     select_backend,
-    get_certificate_argument_spec,
 )
-
 from ansible_collections.community.crypto.plugins.module_utils.crypto.module_backends.certificate_entrust import (
     EntrustCertificateProvider,
     add_entrust_provider_to_argument_spec,
 )
-
 from ansible_collections.community.crypto.plugins.module_utils.crypto.module_backends.certificate_ownca import (
     OwnCACertificateProvider,
     add_ownca_provider_to_argument_spec,
 )
-
 from ansible_collections.community.crypto.plugins.module_utils.crypto.module_backends.certificate_selfsigned import (
     SelfSignedCertificateProvider,
     add_selfsigned_provider_to_argument_spec,
 )
 
-from ansible_collections.community.crypto.plugins.module_utils.crypto.basic import (
-    OpenSSLObjectError,
-)
-
 
 class GenericCertificate(object):
     """Retrieve a certificate using the given module backend."""
+
     def __init__(self, module, module_backend):
         self.check_mode = module.check_mode
+        self.module = module
         self.module_backend = module_backend
         self.changed = False
-        if module.params['content'] is not None:
-            self.module_backend.set_existing(module.params['content'].encode('utf-8'))
+        if module.params["content"] is not None:
+            self.module_backend.set_existing(module.params["content"].encode("utf-8"))
 
     def generate(self, module):
         if self.module_backend.needs_regeneration():
             if not self.check_mode:
                 self.module_backend.generate_certificate()
+            else:
+                self.module.deprecate(
+                    "Check mode support for x509_certificate_pipe will change in community.crypto 3.0.0"
+                    " to behave the same as without check mode. You can get that behavior right now"
+                    " by adding `check_mode: false` to the x509_certificate_pipe task. If you think this"
+                    " breaks your use-case of this module, please create an issue in the"
+                    " community.crypto repository",
+                    version="3.0.0",
+                    collection_name="community.crypto",
+                )
             self.changed = True
 
     def dump(self, check_mode=False):
         result = self.module_backend.dump(include_certificate=True)
-        result.update({
-            'changed': self.changed,
-        })
+        result.update(
+            {
+                "changed": self.changed,
+            }
+        )
         return result
 
 
 def main():
     argument_spec = get_certificate_argument_spec()
-    argument_spec.argument_spec['provider']['required'] = True
+    argument_spec.argument_spec["provider"]["required"] = True
     add_entrust_provider_to_argument_spec(argument_spec)
     add_ownca_provider_to_argument_spec(argument_spec)
     add_selfsigned_provider_to_argument_spec(argument_spec)
-    argument_spec.argument_spec.update(dict(
-        content=dict(type='str'),
-    ))
+    argument_spec.argument_spec.update(
+        dict(
+            content=dict(type="str"),
+        )
+    )
     module = argument_spec.create_ansible_module(
         supports_check_mode=True,
     )
 
     try:
-        provider = module.params['provider']
+        provider = module.params["provider"]
         provider_map = {
-            'entrust': EntrustCertificateProvider,
-            'ownca': OwnCACertificateProvider,
-            'selfsigned': SelfSignedCertificateProvider,
+            "entrust": EntrustCertificateProvider,
+            "ownca": OwnCACertificateProvider,
+            "selfsigned": SelfSignedCertificateProvider,
         }
 
-        backend = module.params['select_crypto_backend']
+        backend = module.params["select_crypto_backend"]
         module_backend = select_backend(module, backend, provider_map[provider]())
         certificate = GenericCertificate(module, module_backend)
         certificate.generate(module)
