@@ -3,50 +3,51 @@
 # GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-from __future__ import (absolute_import, division, print_function)
-__metaclass__ = type
+from __future__ import annotations
 
-DOCUMENTATION = r'''
-    name: online
-    author:
-      - Remy Leone (@remyleone)
-    short_description: Scaleway (previously Online SAS or Online.net) inventory source
-    description:
-        - Get inventory hosts from Scaleway (previously Online SAS or Online.net).
-    options:
-        plugin:
-            description: token that ensures this is a source file for the 'online' plugin.
-            required: true
-            choices: ['online', 'community.general.online']
-        oauth_token:
-            required: true
-            description: Online OAuth token.
-            env:
-                # in order of precedence
-                - name: ONLINE_TOKEN
-                - name: ONLINE_API_KEY
-                - name: ONLINE_OAUTH_TOKEN
-        hostnames:
-            description: List of preference about what to use as an hostname.
-            type: list
-            elements: string
-            default:
-                - public_ipv4
-            choices:
-                - public_ipv4
-                - private_ipv4
-                - hostname
-        groups:
-            description: List of groups.
-            type: list
-            elements: string
-            choices:
-                - location
-                - offer
-                - rpn
-'''
+DOCUMENTATION = r"""
+name: online
+author:
+  - Remy Leone (@remyleone)
+short_description: Scaleway (previously Online SAS or Online.net) inventory source
+description:
+  - Get inventory hosts from Scaleway (previously Online SAS or Online.net).
+options:
+  plugin:
+    description: token that ensures this is a source file for the 'online' plugin.
+    type: string
+    required: true
+    choices: ['online', 'community.general.online']
+  oauth_token:
+    required: true
+    description: Online OAuth token.
+    type: string
+    env:
+      # in order of precedence
+      - name: ONLINE_TOKEN
+      - name: ONLINE_API_KEY
+      - name: ONLINE_OAUTH_TOKEN
+  hostnames:
+    description: List of preference about what to use as an hostname.
+    type: list
+    elements: string
+    default:
+      - public_ipv4
+    choices:
+      - public_ipv4
+      - private_ipv4
+      - hostname
+  groups:
+    description: List of groups.
+    type: list
+    elements: string
+    choices:
+      - location
+      - offer
+      - rpn
+"""
 
-EXAMPLES = r'''
+EXAMPLES = r"""
 # online_inventory.yml file in YAML format
 # Example command line: ansible-inventory --list -i online_inventory.yml
 
@@ -57,7 +58,7 @@ groups:
   - location
   - offer
   - rpn
-'''
+"""
 
 import json
 from sys import version as python_version
@@ -136,7 +137,7 @@ class InventoryModule(BaseInventoryPlugin):
         try:
             response = open_url(url, headers=self.headers)
         except Exception as e:
-            self.display.warning("An error happened while fetching: %s" % url)
+            self.display.warning(f"An error happened while fetching: {url}")
             return None
 
         try:
@@ -243,8 +244,8 @@ class InventoryModule(BaseInventoryPlugin):
         }
 
         self.headers = {
-            'Authorization': "Bearer %s" % token,
-            'User-Agent': "ansible %s Python %s" % (ansible_version, python_version.split(' ', 1)[0]),
+            'Authorization': f"Bearer {token}",
+            'User-Agent': f"ansible {ansible_version} Python {python_version.split(' ', 1)[0]}",
             'Content-type': 'application/json'
         }
 
