@@ -9,7 +9,7 @@ from __future__ import absolute_import, division, print_function
 __metaclass__ = type
 
 
-DOCUMENTATION = '''
+DOCUMENTATION = r"""
 module: htpasswd
 short_description: Manage user files for basic authentication
 description:
@@ -24,13 +24,13 @@ options:
   path:
     type: path
     required: true
-    aliases: [ dest, destfile ]
+    aliases: [dest, destfile]
     description:
       - Path to the file that contains the usernames and passwords.
   name:
     type: str
     required: true
-    aliases: [ username ]
+    aliases: [username]
     description:
       - User name to add or remove.
   password:
@@ -44,19 +44,20 @@ options:
     required: false
     default: "apr_md5_crypt"
     description:
-      - Hashing scheme to be used. As well as the four choices listed
-        here, you can also use any other hash supported by passlib, such as
-        V(portable_apache22) and V(host_apache24); or V(md5_crypt) and V(sha256_crypt),
-        which are Linux passwd hashes. Only some schemes in addition to
-        the four choices below will be compatible with Apache or Nginx, and
-        supported schemes depend on passlib version and its dependencies.
+      - Hashing scheme to be used. As well as the four choices listed here, you can also use any other hash supported by passlib,
+        such as V(portable_apache22) and V(host_apache24); or V(md5_crypt) and V(sha256_crypt), which are Linux passwd hashes.
+        Only some schemes in addition to the four choices below are compatible with Apache or Nginx, and supported schemes
+        depend on C(passlib) version and its dependencies.
       - See U(https://passlib.readthedocs.io/en/stable/lib/passlib.apache.html#passlib.apache.HtpasswdFile) parameter C(default_scheme).
       - 'Some of the available choices might be: V(apr_md5_crypt), V(des_crypt), V(ldap_sha1), V(plaintext).'
+      - 'B(WARNING): The module has no mechanism to determine the O(hash_scheme) of an existing entry, therefore, it does
+        not detect whether the O(hash_scheme) has changed. If you want to change the scheme, you must remove the existing
+        entry and then create a new one using the new scheme.'
     aliases: [crypt_scheme]
   state:
     type: str
     required: false
-    choices: [ present, absent ]
+    choices: [present, absent]
     default: "present"
     description:
       - Whether the user entry should be present or not.
@@ -65,21 +66,21 @@ options:
     type: bool
     default: true
     description:
-      - Used with O(state=present). If V(true), the file will be created
-        if it does not exist. Conversely, if set to V(false) and the file
-        does not exist it will fail.
+      - Used with O(state=present). If V(true), the file is created if it does not exist. Conversely, if set to V(false) and
+        the file does not exist, it fails.
 notes:
-  - "This module depends on the C(passlib) Python library, which needs to be installed on all target systems."
-  - "On Debian, Ubuntu, or Fedora: install C(python-passlib)."
-  - "On RHEL or CentOS: Enable EPEL, then install C(python-passlib)."
-requirements: [ passlib>=1.6 ]
+  - This module depends on the C(passlib) Python library, which needs to be installed on all target systems.
+  - 'On Debian < 11, Ubuntu <= 20.04, or Fedora: install C(python-passlib).'
+  - 'On Debian, Ubuntu: install C(python3-passlib).'
+  - 'On RHEL or CentOS: Enable EPEL, then install C(python-passlib).'
+requirements: [passlib>=1.6]
 author: "Ansible Core Team"
 extends_documentation_fragment:
   - files
   - community.general.attributes
-'''
+"""
 
-EXAMPLES = """
+EXAMPLES = r"""
 - name: Add a user to a password file and ensure permissions are set
   community.general.htpasswd:
     path: /etc/nginx/passwdfile
@@ -87,7 +88,7 @@ EXAMPLES = """
     password: '9s36?;fyNp'
     owner: root
     group: www-data
-    mode: 0640
+    mode: '0640'
 
 - name: Remove a user from a password file
   community.general.htpasswd:
@@ -106,22 +107,16 @@ EXAMPLES = """
 
 import os
 import tempfile
-import traceback
-from ansible.module_utils.basic import AnsibleModule, missing_required_lib
+
+from ansible.module_utils.basic import AnsibleModule
+from ansible_collections.community.general.plugins.module_utils import deps
 from ansible.module_utils.common.text.converters import to_native
 
-from ansible_collections.community.general.plugins.module_utils.version import LooseVersion
 
-PASSLIB_IMP_ERR = None
-try:
+with deps.declare("passlib"):
     from passlib.apache import HtpasswdFile, htpasswd_context
     from passlib.context import CryptContext
-    import passlib
-except ImportError:
-    PASSLIB_IMP_ERR = traceback.format_exc()
-    passlib_installed = False
-else:
-    passlib_installed = True
+
 
 apache_hashes = ["apr_md5_crypt", "des_crypt", "ldap_sha1", "plaintext"]
 
@@ -146,36 +141,20 @@ def present(dest, username, password, hash_scheme, create, check_mode):
         if check_mode:
             return ("Create %s" % dest, True)
         create_missing_directories(dest)
-        if LooseVersion(passlib.__version__) >= LooseVersion('1.6'):
-            ht = HtpasswdFile(dest, new=True, default_scheme=hash_scheme, context=context)
-        else:
-            ht = HtpasswdFile(dest, autoload=False, default=hash_scheme, context=context)
-        if getattr(ht, 'set_password', None):
-            ht.set_password(username, password)
-        else:
-            ht.update(username, password)
+        ht = HtpasswdFile(dest, new=True, default_scheme=hash_scheme, context=context)
+        ht.set_password(username, password)
         ht.save()
         return ("Created %s and added %s" % (dest, username), True)
     else:
-        if LooseVersion(passlib.__version__) >= LooseVersion('1.6'):
-            ht = HtpasswdFile(dest, new=False, default_scheme=hash_scheme, context=context)
-        else:
-            ht = HtpasswdFile(dest, default=hash_scheme, context=context)
+        ht = HtpasswdFile(dest, new=False, default_scheme=hash_scheme, context=context)
 
-        found = None
-        if getattr(ht, 'check_password', None):
-            found = ht.check_password(username, password)
-        else:
-            found = ht.verify(username, password)
+        found = ht.check_password(username, password)
 
         if found:
             return ("%s already present" % username, False)
         else:
             if not check_mode:
-                if getattr(ht, 'set_password', None):
-                    ht.set_password(username, password)
-                else:
-                    ht.update(username, password)
+                ht.set_password(username, password)
                 ht.save()
             return ("Add/update %s" % username, True)
 
@@ -184,10 +163,7 @@ def absent(dest, username, check_mode):
     """ Ensures user is absent
 
     Returns (msg, changed) """
-    if LooseVersion(passlib.__version__) >= LooseVersion('1.6'):
-        ht = HtpasswdFile(dest, new=False)
-    else:
-        ht = HtpasswdFile(dest)
+    ht = HtpasswdFile(dest, new=False)
 
     if username not in ht.users():
         return ("%s not present" % username, False)
@@ -233,20 +209,13 @@ def main():
     create = module.params['create']
     check_mode = module.check_mode
 
-    if not passlib_installed:
-        module.fail_json(msg=missing_required_lib("passlib"), exception=PASSLIB_IMP_ERR)
+    deps.validate(module)
 
+    # TODO double check if this hack below is still needed.
     # Check file for blank lines in effort to avoid "need more than 1 value to unpack" error.
     try:
-        f = open(path, "r")
-    except IOError:
-        # No preexisting file to remove blank lines from
-        f = None
-    else:
-        try:
+        with open(path, "r") as f:
             lines = f.readlines()
-        finally:
-            f.close()
 
         # If the file gets edited, it returns true, so only edit the file if it has blank lines
         strip = False
@@ -260,11 +229,12 @@ def main():
             if check_mode:
                 temp = tempfile.NamedTemporaryFile()
                 path = temp.name
-            f = open(path, "w")
-            try:
-                [f.write(line) for line in lines if line.strip()]
-            finally:
-                f.close()
+            with open(path, "w") as f:
+                f.writelines(line for line in lines if line.strip())
+
+    except IOError:
+        # No preexisting file to remove blank lines from
+        pass
 
     try:
         if state == 'present':
@@ -276,8 +246,9 @@ def main():
             (msg, changed) = absent(path, username, check_mode)
         else:
             module.fail_json(msg="Invalid state: %s" % state)
+            return  # needed to make pylint happy
 
-        check_file_attrs(module, changed, msg)
+        (msg, changed) = check_file_attrs(module, changed, msg)
         module.exit_json(msg=msg, changed=changed)
     except Exception as e:
         module.fail_json(msg=to_native(e))
