@@ -7,62 +7,75 @@
 from __future__ import absolute_import, division, print_function
 __metaclass__ = type
 
-DOCUMENTATION = r'''
----
+DOCUMENTATION = r"""
 module: ipa_hostgroup
 author: Thomas Krahn (@Nosmoht)
 short_description: Manage FreeIPA host-group
 description:
-- Add, modify and delete an IPA host-group using IPA API.
+  - Add, modify and delete an IPA host-group using IPA API.
+attributes:
+  check_mode:
+    support: full
+  diff_mode:
+    support: none
 options:
+  append:
+    description:
+      - If V(true), add the listed O(host) to the O(hostgroup).
+      - If V(false), only the listed O(host) is set in O(hostgroup), removing any other hosts.
+    default: false
+    type: bool
+    version_added: 6.6.0
   cn:
     description:
-    - Name of host-group.
-    - Can not be changed as it is the unique identifier.
+      - Name of host-group.
+      - Can not be changed as it is the unique identifier.
     required: true
     aliases: ["name"]
     type: str
   description:
     description:
-    - Description.
+      - Description.
     type: str
   host:
     description:
-    - List of hosts that belong to the host-group.
-    - If an empty list is passed all hosts will be removed from the group.
-    - If option is omitted hosts will not be checked or changed.
-    - If option is passed all assigned hosts that are not passed will be unassigned from the group.
+      - List of hosts that belong to the host-group.
+      - If an empty list is passed all hosts are removed from the group.
+      - If option is omitted hosts are not checked nor changed.
+      - If option is passed all assigned hosts that are not passed are unassigned from the group.
     type: list
     elements: str
   hostgroup:
     description:
-    - List of host-groups than belong to that host-group.
-    - If an empty list is passed all host-groups will be removed from the group.
-    - If option is omitted host-groups will not be checked or changed.
-    - If option is passed all assigned hostgroups that are not passed will be unassigned from the group.
+      - List of host-groups than belong to that host-group.
+      - If an empty list is passed all host-groups are removed from the group.
+      - If option is omitted host-groups are not checked nor changed.
+      - If option is passed all assigned hostgroups that are not passed are unassigned from the group.
     type: list
     elements: str
   state:
     description:
-    - State to ensure.
+      - State to ensure.
+      - V("absent") and V("disabled") give the same results.
+      - V("present") and V("enabled") give the same results.
     default: "present"
     choices: ["absent", "disabled", "enabled", "present"]
     type: str
 extends_documentation_fragment:
-- community.general.ipa.documentation
+  - community.general.ipa.documentation
+  - community.general.attributes
+"""
 
-'''
-
-EXAMPLES = r'''
+EXAMPLES = r"""
 - name: Ensure host-group databases is present
   community.general.ipa_hostgroup:
     name: databases
     state: present
     host:
-    - db.example.com
+      - db.example.com
     hostgroup:
-    - mysql-server
-    - oracle-server
+      - mysql-server
+      - oracle-server
     ipa_host: ipa.example.com
     ipa_user: admin
     ipa_pass: topsecret
@@ -74,14 +87,14 @@ EXAMPLES = r'''
     ipa_host: ipa.example.com
     ipa_user: admin
     ipa_pass: topsecret
-'''
+"""
 
-RETURN = r'''
+RETURN = r"""
 hostgroup:
   description: Hostgroup as returned by IPA API.
   returned: always
   type: dict
-'''
+"""
 
 import traceback
 
@@ -141,12 +154,13 @@ def ensure(module, client):
     state = module.params['state']
     host = module.params['host']
     hostgroup = module.params['hostgroup']
+    append = module.params['append']
 
     ipa_hostgroup = client.hostgroup_find(name=name)
     module_hostgroup = get_hostgroup_dict(description=module.params['description'])
 
     changed = False
-    if state == 'present':
+    if state in ['present', 'enabled']:
         if not ipa_hostgroup:
             changed = True
             if not module.check_mode:
@@ -162,14 +176,18 @@ def ensure(module, client):
                     client.hostgroup_mod(name=name, item=data)
 
         if host is not None:
-            changed = client.modify_if_diff(name, ipa_hostgroup.get('member_host', []), [item.lower() for item in host],
-                                            client.hostgroup_add_host, client.hostgroup_remove_host) or changed
+            changed = client.modify_if_diff(name, ipa_hostgroup.get('member_host', []),
+                                            [item.lower() for item in host],
+                                            client.hostgroup_add_host,
+                                            client.hostgroup_remove_host,
+                                            append=append) or changed
 
         if hostgroup is not None:
             changed = client.modify_if_diff(name, ipa_hostgroup.get('member_hostgroup', []),
                                             [item.lower() for item in hostgroup],
                                             client.hostgroup_add_hostgroup,
-                                            client.hostgroup_remove_hostgroup) or changed
+                                            client.hostgroup_remove_hostgroup,
+                                            append=append) or changed
 
     else:
         if ipa_hostgroup:
@@ -186,7 +204,8 @@ def main():
                          description=dict(type='str'),
                          host=dict(type='list', elements='str'),
                          hostgroup=dict(type='list', elements='str'),
-                         state=dict(type='str', default='present', choices=['present', 'absent', 'enabled', 'disabled']))
+                         state=dict(type='str', default='present', choices=['present', 'absent', 'enabled', 'disabled']),
+                         append=dict(type='bool', default=False))
 
     module = AnsibleModule(argument_spec=argument_spec,
                            supports_check_mode=True)
