@@ -1,8 +1,10 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
+
 # Copyright: (c) 2019-2020, Ansible Project
 # Copyright: (c) 2019-2020, Naveenkumar G P <ngp@vmware.com>
-# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
+# GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
+# SPDX-License-Identifier: GPL-3.0-or-later
 
 from __future__ import absolute_import, division, print_function
 __metaclass__ = type
@@ -15,50 +17,44 @@ short_description: List and Export VMware vCenter infra profile configs.
 description:
 - Module to manage VMware vCenter infra profile configs.
 - vCenter infra profile Library feature is introduced in vSphere 7.0 version, so this module is not supported in the earlier versions of vSphere.
-- All variables and VMware object names are case sensitive.
-version_added: '1.0.0'
 author:
 - Naveenkumar G P (@ngp)
-notes:
-- Tested on vSphere 7.0
 requirements:
-- python >= 2.7
-- PyVmomi
 - vSphere Automation SDK
 options:
     decryption_key:
       description:
       - decryption_key argument for while doing import profile task as of now its not taken into account form API team.
       type: str
-      required: False
+      required: false
     encryption_key:
       description:
       - encryption_key argument for while doing import profile task as of now its not taken into account form API team.
       type: str
-      required: False
+      required: false
     api:
       description:
       - API which needs to be executed
       type: str
-      required: False
+      required: false
       choices: [ export, import, list, validate ]
     config_path:
       description:
       - Config file path which contains infra profile config JSON data, supports both relative and absolute path.
-      - This parameter is required only when C(import),C(validate) APIs are being used.
+      - This parameter is required only when V(import),V(validate) APIs are being used.
       type: str
-      required: False
+      required: false
     profiles:
       description:
       - A list of profile names to be exported, imported, and validated.
-      - This parameter is not required while running for List API, not for C(export),C(import) and C(validate).
+      - This parameter is not required while running for List API, not for V(export),V(import) and V(validate).
       type: str
-      required: False
+      required: false
     description:
       description:
       - Description of about encryption or decryption key.
       type: str
-      required: False
+      required: false
 extends_documentation_fragment:
 - community.vmware.vmware_rest_client.documentation
 '''
@@ -150,22 +146,12 @@ import_profile:
 '''
 
 from ansible.module_utils.basic import AnsibleModule
-from ansible_collections.community.vmware.plugins.module_utils.version import LooseVersion
 from ansible_collections.community.vmware.plugins.module_utils.vmware_rest_client import VmwareRestClient
-from ansible_collections.community.vmware.plugins.module_utils.vmware import PyVmomi
+from ansible_collections.community.vmware.plugins.module_utils._argument_spec import rest_compatible_argument_spec
 import json
 import time
 
 
-class VcVersionChecker(PyVmomi):
-    def __init__(self, module):
-        super(VcVersionChecker, self).__init__(module)
-
-    def check_vc_version(self):
-        if LooseVersion(self.content.about.version) < LooseVersion('7'):
-            self.module.fail_json(msg="vCenter version is less than 7.0.0 Please specify vCenter with version greater than or equal to 7.0.0")
-
-
 class VcenterProfile(VmwareRestClient):
 
     def __init__(self, module):
@@ -236,7 +222,7 @@ class VcenterProfile(VmwareRestClient):
 
 
 def main():
-    argument_spec = VmwareRestClient.vmware_client_argument_spec()
+    argument_spec = rest_compatible_argument_spec()
     argument_spec.update(
         encryption_key=dict(type='str', required=False, no_log=True),
         description=dict(type='str', required=False),
@@ -248,8 +234,6 @@ def main():
     module = AnsibleModule(argument_spec=argument_spec, supports_check_mode=True)
     result = {'failed': False, 'changed': False}
     vmware_vc_infra_profile = VcenterProfile(module)
-    vmware_vc_version = VcVersionChecker(module)
-    vmware_vc_version.check_vc_version()
 
     if module.params['api'].lower() == "list":
         if module.check_mode:
