@@ -2,9 +2,9 @@
 # -*- coding: utf-8 -*-
 
 #
-# Dell EMC OpenManage Ansible Modules
-# Version 4.0.0
-# Copyright (C) 2019-2021 Dell Inc. or its subsidiaries. All Rights Reserved.
+# Dell OpenManage Ansible Modules
+# Version 9.3.0
+# Copyright (C) 2019-2025 Dell Inc. or its subsidiaries. All Rights Reserved.
 
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 #
@@ -30,19 +30,38 @@ options:
             - Firmware Image location URI or local path.
             - For example- U(http://<web_address>/components.exe) or /home/firmware_repo/component.exe.
         type: str
-        required: True
+        required: true
     transfer_protocol:
         description: Protocol used to transfer the firmware image file. Applicable for URI based update.
         type: str
         default: HTTP
         choices: ["CIFS", "FTP", "HTTP", "HTTPS", "NSF", "OEM", "SCP", "SFTP", "TFTP"]
+    job_wait:
+        description: Provides the option to wait for job completion.
+        type: bool
+        default: true
+    job_wait_timeout:
+        type: int
+        description:
+            - The maximum wait time of I(job_wait) in seconds. The job is tracked only for this duration.
+            - This option is applicable when I(job_wait) is C(true).
+            - "Note: If a firmware update needs a reboot, the job will get scheduled and waits for
+              no of seconds specfied in I(job_wait_time). to reduce the wait time either give
+              I(job_wait_time) minimum or make I(job_wait)as false and retrigger."
+        default: 3600
 requirements:
-    - "python >= 2.7.5"
+    - "python >= 3.9.6"
     - "urllib3"
 author:
     - "Felix Stephen (@felixs88)"
+    - "Husniya Hameed (@husniya_hameed)"
+    - "Shivam Sharma (@Shivam-Sharma)"
+    - "Kritika Bhateja (@Kritika_Bhateja)"
+    - "Abhishek Sinha (@ABHISHEK-SINHA10)"
 notes:
     - Run this module from a system that has direct access to Redfish APIs.
+    - This module supports both IPv4 and IPv6 addresses.
+    - This module supports only iDRAC9 and above.
     - This module does not support C(check_mode).
 """
 
@@ -53,14 +72,27 @@ EXAMPLES = """
     baseuri: "192.168.0.1"
     username: "user_name"
     password: "user_password"
+    ca_path: "/path/to/ca_cert.pem"
     image_uri: "http://192.168.0.2/firmware_repo/component.exe"
     transfer_protocol: "HTTP"
 
+- name: Update the firmware from a single executable file available in a HTTP protocol with job_Wait
+  dellemc.openmanage.redfish_firmware:
+    baseuri: "192.168.0.1"
+    username: "user_name"
+    password: "user_password"
+    ca_path: "/path/to/ca_cert.pem"
+    image_uri: "http://192.168.0.2/firmware_repo/component.exe"
+    transfer_protocol: "HTTP"
+    job_wait: true
+    job_wait_timeout: 600
+
 - name: Update the firmware from a single executable file available in a local path
   dellemc.openmanage.redfish_firmware:
     baseuri: "192.168.0.1"
     username: "user_name"
     password: "user_password"
+    ca_path: "/path/to/ca_cert.pem"
     image_uri: "/home/firmware_repo/component.exe"
 """
 
@@ -70,7 +102,7 @@ msg:
   description: Overall status of the firmware update task.
   returned: always
   type: str
-  sample: Successfully submitted the firmware update task.
+  sample: "Successfully updated the firmware."
 task:
   description: Returns ID and URI of the created task.
   returned: success
@@ -110,8 +142,10 @@ error_info:
 
 import json
 import os
-from ansible_collections.dellemc.openmanage.plugins.module_utils.redfish import Redfish
-from ansible.module_utils.basic import AnsibleModule, missing_required_lib
+import time
+from ssl import SSLError
+from ansible_collections.dellemc.openmanage.plugins.module_utils.redfish import Redfish, RedfishAnsibleModule
+from ansible.module_utils.basic import missing_required_lib
 from ansible.module_utils.urls import ConnectionError, SSLValidationError
 from ansible.module_utils.six.moves.urllib.error import URLError, HTTPError
 
@@ -123,6 +157,16 @@ except ImportError:
     HAS_LIB = False
 
 UPDATE_SERVICE = "UpdateService"
+JOB_URI = "JobService/Jobs/{job_id}"
+JOB_WAIT_MSG = 'Job wait timed out after {0} seconds.'
+FAIL_JOB_MSG = "Firmware update failed."
+SUCCESS_JOB_MSG = "Successfully updated the firmware."
+SCHEDULE_JOB_MSG = "Successfully scheduled the firmware job."
+JOBSTATUS_SUCCESS = "success"
+JOBSTATUS_FAILED = "failed"
+JOBSTATUS_TIMED_OUT = "timed_out"
+JOBSTATUS_SCHEDULED = "scheduled"
+JOBSTATUS_ERRORED = "errored"
 
 
 def _encode_form_data(payload_file):
@@ -172,8 +216,7 @@ def firmware_update(obj, module):
             data, ctype = _encode_form_data(binary_payload)
         headers = {"If-Match": resp_inv.headers.get("etag")}
         headers.update({"Content-Type": ctype})
-        upload_status = obj.invoke_request("POST", push_uri, data=data, headers=headers, dump=False,
-                                           api_timeout=100)
+        upload_status = obj.invoke_request("POST", push_uri, data=data, headers=headers, dump=False, api_timeout=module.params["timeout"])
         if upload_status.status_code == 201:
             payload = {"ImageURI": upload_status.headers.get("location")}
             update_status = obj.invoke_request("POST", update_uri, data=payload)
@@ -182,16 +225,55 @@ def firmware_update(obj, module):
     return update_status
 
 
+def wait_for_job_completion(module, job_uri, job_wait_timeout=900, interval=30):
+    try:
+        with Redfish(module.params, req_session=False) as obj:
+            track_counter = 0
+            final_jobstatus = ""
+            job_msg = ""
+            while track_counter <= job_wait_timeout:
+                try:
+                    response = obj.invoke_request("GET", "{0}{1}".format(obj.root_uri, job_uri))
+                    if response.json_data.get("PercentComplete") == 100 and response.json_data.get("JobState") == "Completed":
+                        if response.json_data.get("JobStatus") == "OK":
+                            final_jobstatus = JOBSTATUS_SUCCESS
+                            job_msg = SUCCESS_JOB_MSG
+                        else:
+                            final_jobstatus = JOBSTATUS_FAILED
+                            job_msg = FAIL_JOB_MSG
+                        break
+                    track_counter += interval
+                    time.sleep(interval)
+                except (HTTPError, URLError):
+                    track_counter += interval
+                    time.sleep(interval)
+            # TIMED OUT
+            # when job is scheduled
+            if not final_jobstatus:
+                if response.json_data.get("PercentComplete") == 0 and response.json_data.get("JobState") == "Starting":
+                    final_jobstatus = JOBSTATUS_SCHEDULED
+                    job_msg = SCHEDULE_JOB_MSG
+                # when job timed out
+                else:
+                    job_msg = JOB_WAIT_MSG.format(job_wait_timeout)
+                    final_jobstatus = JOBSTATUS_TIMED_OUT
+    except Exception as error_message:
+        job_msg = str(error_message)
+        module.exit_json(msg=str(job_msg))
+        final_jobstatus = JOBSTATUS_ERRORED
+    return final_jobstatus, job_msg
+
+
 def main():
-    module = AnsibleModule(
-        argument_spec={
-            "baseuri": {"required": True, "type": "str"},
-            "username": {"required": True, "type": "str"},
-            "password": {"required": True, "type": "str", "no_log": True},
-            "image_uri": {"required": True, "type": "str"},
-            "transfer_protocol": {"type": "str", "default": "HTTP",
-                                  "choices": ["CIFS", "FTP", "HTTP", "HTTPS", "NSF", "OEM", "SCP", "SFTP", "TFTP"]},
-        },
+    specs = {
+        "image_uri": {"required": True, "type": "str"},
+        "transfer_protocol": {"type": "str", "default": "HTTP", "choices": ["CIFS", "FTP", "HTTP", "HTTPS", "NSF", "OEM", "SCP", "SFTP", "TFTP"]},
+        "job_wait": {"required": False, "type": 'bool', "default": True},
+        "job_wait_timeout": {"required": False, "type": "int", "default": 3600}
+    }
+
+    module = RedfishAnsibleModule(
+        argument_spec=specs,
         supports_check_mode=False)
     if not HAS_LIB:
         module.fail_json(msg=missing_required_lib("urllib3"))
@@ -202,13 +284,24 @@ def main():
             if status.success:
                 message = "Successfully submitted the firmware update task."
                 task_uri = status.headers.get("Location")
-                task_id = task_uri.split("/")[-1]
-                module.exit_json(msg=message, task={"id": task_id, "uri": task_uri}, changed=True)
-            module.fail_json(msg=message, error_info=json.loads(status))
+                job_id = task_uri.split("/")[-1]
+            else:
+                module.fail_json(msg=message, error_info=json.loads(status))
+        job_wait = module.params['job_wait']
+        job_wait_timeout = module.params['job_wait_timeout']
+        if job_wait and job_wait_timeout > 0:
+            job_uri = JOB_URI.format(job_id=job_id)
+            job_resp, job_msg = wait_for_job_completion(module, job_uri, job_wait_timeout=module.params['job_wait_timeout'])
+            if job_resp == JOBSTATUS_FAILED:
+                module.exit_json(msg=job_msg, task={"id": job_id, "uri": JOB_URI.format(job_id=job_id)}, failed=True)
+            else:
+                module.exit_json(msg=job_msg, task={"id": job_id, "uri": JOB_URI.format(job_id=job_id)}, changed=True)
+        else:
+            module.exit_json(msg=message, task={"id": job_id, "uri": JOB_URI.format(job_id=job_id)}, changed=True)
     except HTTPError as err:
-        module.fail_json(msg=str(err), error_info=json.load(err))
+        module.exit_json(msg=str(err), error_info=json.load(err), failed=True)
     except (RuntimeError, URLError, SSLValidationError, ConnectionError, KeyError,
-            ImportError, ValueError, TypeError, IOError, AssertionError) as e:
+            ImportError, ValueError, TypeError, IOError, AssertionError, OSError, SSLError) as e:
         module.fail_json(msg=str(e))
 
 
