@@ -96,9 +96,10 @@ options:
             count:
                 type: int
                 description: Count.
-            extension-type:
+            extension_type:
+                aliases: ['extension-type']
                 type: str
-                description: Deprecated, please rename it to extension_type. Extension type.
+                description: Extension type.
                 choices:
                     - 'wan-extension'
                     - 'lan-extension'
@@ -121,6 +122,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -137,11 +139,11 @@ EXAMPLES = '''
         template: <your own value>
         state: present # <value in [present, absent]>
         fmg_fabric_authorization_template_platforms:
-          count: <integer>
-          extension_type: <value in [wan-extension, lan-extension]>
-          fortilink: <string>
-          prefix: <string>
-          type: <value in [ap, extender, switch]>
+          # count: <integer>
+          # extension_type: <value in [wan-extension, lan-extension]>
+          # fortilink: <string>
+          # prefix: <string>
+          # type: <value in [ap, extender, switch]>
 '''
 
 RETURN = '''
@@ -185,23 +187,15 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/fmg/fabric/authorization/template/{template}/platforms',
         '/pm/config/global/obj/fmg/fabric/authorization/template/{template}/platforms'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/fmg/fabric/authorization/template/{template}/platforms/{platforms}',
-        '/pm/config/global/obj/fmg/fabric/authorization/template/{template}/platforms/{platforms}'
-    ]
-
     url_params = ['adom', 'template']
     module_primary_key = None
     module_arg_spec = {
@@ -217,7 +211,6 @@ def main():
                 'prefix': {'v_range': [['7.2.1', '']], 'type': 'str'},
                 'type': {'v_range': [['7.2.1', '']], 'choices': ['ap', 'extender', 'switch'], 'type': 'str'}
             }
-
         }
     }
 
@@ -226,14 +219,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'fmg_fabric_authorization_template_platforms'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
