@@ -76,12 +76,14 @@ options:
         required: false
         type: dict
         suboptions:
-            retention-days:
+            retention_days:
+                aliases: ['retention-days']
                 type: int
-                description: Deprecated, please rename it to retention_days. Number of days for interface data storage.
-            sampling-interval:
+                description: Number of days for interface data storage.
+            sampling_interval:
+                aliases: ['sampling-interval']
                 type: int
-                description: Deprecated, please rename it to sampling_interval. Interval of receiving interface data from FortiGates in seconds.
+                description: Interval of receiving interface data from FortiGates in seconds.
             status:
                 type: str
                 description:
@@ -91,10 +93,10 @@ options:
                 choices:
                     - 'disable'
                     - 'enable'
-            billing-report:
+            billing_report:
+                aliases: ['billing-report']
                 type: str
                 description:
-                    - Deprecated, please rename it to billing_report.
                     - Disable/Enable billing report feature.
                     - disable - Disable billing report.
                     - enable - Enable billing report.
@@ -107,6 +109,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -120,10 +123,10 @@ EXAMPLES = '''
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         system_log_interfacestats:
-          retention_days: <integer>
-          sampling_interval: <integer>
-          status: <value in [disable, enable]>
-          billing_report: <value in [disable, enable]>
+          # retention_days: <integer>
+          # sampling_interval: <integer>
+          # status: <value in [disable, enable]>
+          # billing_report: <value in [disable, enable]>
 '''
 
 RETURN = '''
@@ -167,21 +170,14 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/cli/global/system/log/interface-stats'
     ]
-
-    perobject_jrpc_urls = [
-        '/cli/global/system/log/interface-stats/{interface-stats}'
-    ]
-
     url_params = []
     module_primary_key = None
     module_arg_spec = {
@@ -194,7 +190,6 @@ def main():
                 'status': {'v_range': [['6.2.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
                 'billing-report': {'v_range': [['6.4.3', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
             }
-
         }
     }
 
@@ -203,14 +198,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'system_log_interfacestats'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('partial crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_partial_curd(argument_specs=module_arg_spec)
+    fmgr.process_partial_crud()
 
     module.exit_json(meta=module.params)
 
