@@ -12,7 +12,7 @@ ANSIBLE_METADATA = {'status': ['preview'],
 DOCUMENTATION = '''
 ---
 module: fmgr_templategroup
-short_description: Cli template group
+short_description: Require device/vdom scope member
 description:
     - This module is able to configure a FortiManager device.
     - Examples include all parameters and values which need to be adjusted to data sources before usage.
@@ -96,9 +96,10 @@ options:
                 type: list
                 elements: str
                 description: Member.
-            modification-time:
+            modification_time:
+                aliases: ['modification-time']
                 type: str
-                description: Deprecated, please rename it to modification_time. Modification time.
+                description: Modification time.
             name:
                 type: str
                 description: Name.
@@ -106,18 +107,38 @@ options:
             variables:
                 type: raw
                 description: (list) Variables.
+            option:
+                type: list
+                elements: str
+                description: Option.
+                choices:
+                    - 'sdwan-overlay'
+                    - 'sdwan-manager'
+            scope_member:
+                aliases: ['scope member']
+                type: list
+                elements: dict
+                description: Scope member.
+                suboptions:
+                    name:
+                        type: str
+                        description: Name.
+                    vdom:
+                        type: str
+                        description: Vdom.
 '''
 
 EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
     ansible_httpapi_port: 443
   tasks:
-    - name: Cli template group
+    - name: Require device/vdom scope member
       fortinet.fortimanager.fmgr_templategroup:
         # bypass_validation: false
         workspace_locking_adom: <value in [global, custom adom including root]>
@@ -127,11 +148,17 @@ EXAMPLES = '''
         adom: <your own value>
         state: present # <value in [present, absent]>
         templategroup:
-          description: <string>
-          member: <list or string>
-          modification_time: <string>
-          name: <string>
-          variables: <list or string>
+          name: "your value" # Required variable, string
+          # description: <string>
+          # member: <list or string>
+          # modification_time: <string>
+          # variables: <list or string>
+          # option:
+          #   - "sdwan-overlay"
+          #   - "sdwan-manager"
+          # scope_member:
+          #   - name: <string>
+          #     vdom: <string>
 '''
 
 RETURN = '''
@@ -175,23 +202,15 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/cli/template-group',
         '/pm/config/global/obj/cli/template-group'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/cli/template-group/{template-group}',
-        '/pm/config/global/obj/cli/template-group/{template-group}'
-    ]
-
     url_params = ['adom']
     module_primary_key = 'name'
     module_arg_spec = {
@@ -204,9 +223,15 @@ def main():
                 'member': {'type': 'list', 'elements': 'str'},
                 'modification-time': {'v_range': [['6.0.0', '7.0.3']], 'type': 'str'},
                 'name': {'required': True, 'type': 'str'},
-                'variables': {'v_range': [['7.2.3', '']], 'type': 'raw'}
+                'variables': {'v_range': [['7.2.3', '']], 'type': 'raw'},
+                'option': {'v_range': [['7.6.0', '']], 'type': 'list', 'choices': ['sdwan-overlay', 'sdwan-manager'], 'elements': 'str'},
+                'scope member': {
+                    'v_range': [['7.4.7', '7.4.7']],
+                    'type': 'list',
+                    'options': {'name': {'v_range': [['7.4.7', '7.4.7']], 'type': 'str'}, 'vdom': {'v_range': [['7.4.7', '7.4.7']], 'type': 'str'}},
+                    'elements': 'dict'
+                }
             }
-
         }
     }
 
@@ -215,14 +240,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'templategroup'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
