@@ -5,6 +5,7 @@
 
 from __future__ import absolute_import, division, print_function
 
+
 __metaclass__ = type
 
 """
@@ -15,7 +16,8 @@ the given network resource.
 """
 
 import re
-from ansible_collections.ansible.netcommon.plugins.module_utils.network.common.network_template import (
+
+from ansible_collections.ansible.netcommon.plugins.module_utils.network.common.rm_base.network_template import (
     NetworkTemplate,
 )
 
@@ -26,11 +28,11 @@ def _tmplt_bgp_af_aggregate_address(config_data):
     config_data = config_data["address_family"]
     if config_data["aggregate_address"].get("as_set"):
         command += afi + " aggregate-address {prefix} as-set".format(
-            **config_data["aggregate_address"]
+            **config_data["aggregate_address"],
         )
     if config_data["aggregate_address"].get("summary_only"):
         command += afi + " aggregate-address {prefix} summary-only".format(
-            **config_data["aggregate_address"]
+            **config_data["aggregate_address"],
         )
     return command
 
@@ -38,12 +40,10 @@ def _tmplt_bgp_af_aggregate_address(config_data):
 def _tmplt_bgp_af_redistribute_metric(config_data):
     if config_data["address_family"]["redistribute"].get("metric"):
         afi = config_data["address_family"]["afi"] + "-unicast"
-        command = "protocols bgp {as_number} address-family ".format(
-            **config_data
-        )
+        command = "protocols bgp {as_number} address-family ".format(**config_data)
         if config_data["address_family"]["redistribute"].get("metric"):
             command += afi + " redistribute {protocol} metric {metric}".format(
-                **config_data["address_family"]["redistribute"]
+                **config_data["address_family"]["redistribute"],
             )
         return command
 
@@ -51,15 +51,10 @@ def _tmplt_bgp_af_redistribute_metric(config_data):
 def _tmplt_bgp_af_redistribute_route_map(config_data):
     if config_data["address_family"]["redistribute"].get("route_map"):
         afi = config_data["address_family"]["afi"] + "-unicast"
-        command = "protocols bgp {as_number} address-family ".format(
-            **config_data
-        )
+        command = "protocols bgp {as_number} address-family ".format(**config_data)
         if config_data["address_family"]["redistribute"].get("route_map"):
-            command += (
-                afi
-                + " redistribute {protocol} route-map {route_map}".format(
-                    **config_data["address_family"]["redistribute"]
-                )
+            command += afi + " redistribute {protocol} route-map {route_map}".format(
+                **config_data["address_family"]["redistribute"],
             )
         return command
 
@@ -67,12 +62,10 @@ def _tmplt_bgp_af_redistribute_route_map(config_data):
 def _tmplt_bgp_af_redistribute_table(config_data):
     if config_data["address_family"]["redistribute"].get("table"):
         afi = config_data["address_family"]["afi"] + "-unicast"
-        command = "protocols bgp {as_number} address-family ".format(
-            **config_data
-        )
+        command = "protocols bgp {as_number} address-family ".format(**config_data)
         if config_data["address_family"]["redistribute"].get("table"):
             command += afi + " table {table}".format(
-                **config_data["address_family"]["redistribute"]
+                **config_data["address_family"]["redistribute"],
             )
         return command
 
@@ -81,9 +74,7 @@ def _tmplt_bgp_af_delete_redistribute(config_data):
     afi = config_data["address_family"]["afi"] + "-unicast"
     command = "protocols bgp {as_number} address-family ".format(**config_data)
     config_data = config_data["address_family"]
-    command += afi + " redistribute {protocol}".format(
-        **config_data["redistribute"]
-    )
+    command += afi + " redistribute {protocol}".format(**config_data["redistribute"])
     return command
 
 
@@ -91,18 +82,11 @@ def _tmplt_bgp_af_neighbor_distribute_list(config_data):
     command = []
     afi = config_data["neighbors"]["address_family"]["afi"] + "-unicast"
     cmd = "protocols bgp {as_number} neighbor ".format(**config_data)
-    cmd += "{neighbor_address} address-family ".format(
-        **config_data["neighbors"]
-    )
+    cmd += "{neighbor_address} address-family ".format(**config_data["neighbors"])
     config_data = config_data["neighbors"]["address_family"]
     for list_el in config_data["distribute_list"]:
         command.append(
-            cmd
-            + afi
-            + " distribute-list "
-            + list_el["action"]
-            + " "
-            + str(list_el["acl"])
+            cmd + afi + " distribute-list " + list_el["action"] + " " + str(list_el["acl"]),
         )
     return command
 
@@ -111,18 +95,11 @@ def _tmplt_bgp_af_neighbor_route_map(config_data):
     command = []
     afi = config_data["neighbors"]["address_family"]["afi"] + "-unicast"
     cmd = "protocols bgp {as_number} neighbor ".format(**config_data)
-    cmd += "{neighbor_address} address-family ".format(
-        **config_data["neighbors"]
-    )
+    cmd += "{neighbor_address} address-family ".format(**config_data["neighbors"])
     config_data = config_data["neighbors"]["address_family"]
     for list_el in config_data["route_map"]:
         command.append(
-            cmd
-            + afi
-            + " route-map "
-            + list_el["action"]
-            + " "
-            + str(list_el["route_map"])
+            cmd + afi + " route-map " + list_el["action"] + " " + str(list_el["route_map"]),
         )
     return command
 
@@ -131,18 +108,11 @@ def _tmplt_bgp_af_neighbor_prefix_list(config_data):
     command = []
     afi = config_data["neighbors"]["address_family"]["afi"] + "-unicast"
     cmd = "protocols bgp {as_number} neighbor ".format(**config_data)
-    cmd += "{neighbor_address} address-family ".format(
-        **config_data["neighbors"]
-    )
+    cmd += "{neighbor_address} address-family ".format(**config_data["neighbors"])
     config_data = config_data["neighbors"]["address_family"]
     for list_el in config_data["prefix_list"]:
         command.append(
-            cmd
-            + afi
-            + " prefix-list "
-            + list_el["action"]
-            + " "
-            + str(list_el["prefix_list"])
+            cmd + afi + " prefix-list " + list_el["action"] + " " + str(list_el["prefix_list"]),
         )
     return command
 
@@ -151,18 +121,11 @@ def _tmplt_bgp_af_neighbor_filter_list(config_data):
     command = []
     afi = config_data["neighbors"]["address_family"]["afi"] + "-unicast"
     cmd = "protocols bgp {as_number} neighbor ".format(**config_data)
-    cmd += "{neighbor_address} address-family ".format(
-        **config_data["neighbors"]
-    )
+    cmd += "{neighbor_address} address-family ".format(**config_data["neighbors"])
     config_data = config_data["neighbors"]["address_family"]
     for list_el in config_data["filter_list"]:
         command.append(
-            cmd
-            + afi
-            + " filter-list "
-            + list_el["action"]
-            + " "
-            + str(list_el["path_list"])
+            cmd + afi + " filter-list " + list_el["action"] + " " + str(list_el["path_list"]),
         )
     return command
 
@@ -171,9 +134,7 @@ def _tmplt_bgp_af_neighbor_attribute(config_data):
     command = []
     afi = config_data["neighbors"]["address_family"]["afi"] + "-unicast"
     cmd = "protocols bgp {as_number} neighbor ".format(**config_data)
-    cmd += "{neighbor_address} address-family ".format(
-        **config_data["neighbors"]
-    )
+    cmd += "{neighbor_address} address-family ".format(**config_data["neighbors"])
     config_data = config_data["neighbors"]["address_family"]
     for k in config_data["attribute_unchanged"].keys():
         if config_data["attribute_unchanged"][k]:
@@ -187,10 +148,7 @@ def _tmplt_bgp_af_neighbor_delete(config_data):
     afi = config_data["neighbors"]["address_family"]["afi"] + "-unicast"
     command = "protocols bgp {as_number} ".format(**config_data)
     command += (
-        "neighbor {neighbor_address} address-family ".format(
-            **config_data["neighbors"]
-        )
-        + afi
+        "neighbor {neighbor_address} address-family ".format(**config_data["neighbors"]) + afi
     )
     config_data = config_data["neighbors"]["address_family"]
     if config_data.get("allowas_in"):
@@ -238,10 +196,7 @@ def _tmplt_bgp_af_neighbor(config_data):
     afi = config_data["neighbors"]["address_family"]["afi"] + "-unicast"
     command = "protocols bgp {as_number} ".format(**config_data)
     command += (
-        "neighbor {neighbor_address} address-family ".format(
-            **config_data["neighbors"]
-        )
-        + afi
+        "neighbor {neighbor_address} address-family ".format(**config_data["neighbors"]) + afi
     )
     config_data = config_data["neighbors"]["address_family"]
     if config_data.get("allowas_in"):
@@ -255,9 +210,7 @@ def _tmplt_bgp_af_neighbor(config_data):
         elif config_data["capability"].get("orf"):
             command += " prefix-list {orf}".format(**config_data["capability"])
     elif config_data.get("default_originate"):
-        command += " default-originate route-map {default_originate}".format(
-            **config_data
-        )
+        command += " default-originate route-map {default_originate}".format(**config_data)
     elif config_data.get("maximum_prefix"):
         command += " maximum-prefix {maximum_prefix}".format(**config_data)
     elif config_data.get("nexthop_local"):
@@ -285,7 +238,10 @@ class Bgp_address_familyTemplate(NetworkTemplate):
     def __init__(self, lines=None, module=None):
         prefix = {"set": "set", "remove": "delete"}
         super(Bgp_address_familyTemplate, self).__init__(
-            lines=lines, tmplt=self, prefix=prefix, module=module
+            lines=lines,
+            tmplt=self,
+            prefix=prefix,
+            module=module,
         )
 
     # fmt: off
@@ -310,9 +266,9 @@ class Bgp_address_familyTemplate(NetworkTemplate):
                 "address_family": {
                     "{{ afi }}": {
                         "afi": "{{ afi }}",
-                    }
-                }
-            }
+                    },
+                },
+            },
         },
         {
             "name": "aggregate_address",
@@ -344,12 +300,12 @@ class Bgp_address_familyTemplate(NetworkTemplate):
                             {
                                 "prefix": "{{ address }}",
                                 "as_set": "{{ True if as_set is defined }}",
-                                "summary_only": "{{ True if summary_only is defined }}"
-                            }
-                        ]
-                    }
-                }
-            }
+                                "summary_only": "{{ True if summary_only is defined }}",
+                            },
+                        ],
+                    },
+                },
+            },
         },
         {
             "name": "network.backdoor",
@@ -378,12 +334,12 @@ class Bgp_address_familyTemplate(NetworkTemplate):
                         "networks": [
                             {
                                 "prefix": "{{ address }}",
-                                "backdoor": "{{ True }}"
-                            }
-                        ]
-                    }
-                }
-            }
+                                "backdoor": "{{ True }}",
+                            },
+                        ],
+                    },
+                },
+            },
         },
         {
             "name": "network.path_limit",
@@ -414,12 +370,12 @@ class Bgp_address_familyTemplate(NetworkTemplate):
                         "networks": [
                             {
                                 "prefix": "{{ address }}",
-                                "path_limit": "{{ limit|int }}"
-                            }
-                        ]
-                    }
-                }
-            }
+                                "path_limit": "{{ limit|int }}",
+                            },
+                        ],
+                    },
+                },
+            },
         },
         {
             "name": "network.route_map",
@@ -450,12 +406,12 @@ class Bgp_address_familyTemplate(NetworkTemplate):
                         "networks": [
                             {
                                 "prefix": "{{ address }}",
-                                "route_map": "{{ map }}"
-                            }
-                        ]
-                    }
-                }
-            }
+                                "route_map": "{{ map }}",
+                            },
+                        ],
+                    },
+                },
+            },
         },
         {
             "name": "redistribute.metric",
@@ -485,12 +441,12 @@ class Bgp_address_familyTemplate(NetworkTemplate):
                         "redistribute": [
                             {
                                 "protocol": "{{ proto }}",
-                                "metric": "{{ val|int }}"
-                            }
-                        ]
-                    }
-                }
-            }
+                                "metric": "{{ val|int }}",
+                            },
+                        ],
+                    },
+                },
+            },
         },
         {
             "name": "redistribute.route_map",
@@ -520,12 +476,12 @@ class Bgp_address_familyTemplate(NetworkTemplate):
                         "redistribute": [
                             {
                                 "protocol": "{{ proto }}",
-                                "route_map": "{{ map }}"
-                            }
-                        ]
-                    }
-                }
-            }
+                                "route_map": "{{ map }}",
+                            },
+                        ],
+                    },
+                },
+            },
         },
         {
             "name": "redistribute.table",
@@ -553,12 +509,12 @@ class Bgp_address_familyTemplate(NetworkTemplate):
                         "afi": "{{ afi }}",
                         "redistribute": [
                             {
-                                "table": "{{ tab }}"
-                            }
-                        ]
-                    }
-                }
-            }
+                                "table": "{{ tab }}",
+                            },
+                        ],
+                    },
+                },
+            },
         },
         {
             "name": "neighbors",
@@ -581,9 +537,9 @@ class Bgp_address_familyTemplate(NetworkTemplate):
                 "neighbors": {
                     "{{ address }}": {
                         "neighbor_address": "{{ address }}",
-                    }
-                }
-            }
+                    },
+                },
+            },
         },
         {
             "name": "neighbors.address_family",
@@ -610,11 +566,11 @@ class Bgp_address_familyTemplate(NetworkTemplate):
                         "address_family": {
                             "{{ afi }}": {
                                 "afi": "{{ afi }}",
-                            }
-                        }
-                    }
-                }
-            }
+                            },
+                        },
+                    },
+                },
+            },
         },
         {
             "name": "neighbors.allowas_in",
@@ -645,12 +601,12 @@ class Bgp_address_familyTemplate(NetworkTemplate):
                         "address_family": {
                             "{{ afi }}": {
                                 "afi": "{{ afi }}",
-                                "allowas_in": "{{ num }}"
-                            }
-                        }
-                    }
-                }
-            }
+                                "allowas_in": "{{ num }}",
+                            },
+                        },
+                    },
+                },
+            },
         },
         {
             "name": "neighbors.as_override",
@@ -679,12 +635,12 @@ class Bgp_address_familyTemplate(NetworkTemplate):
                         "address_family": {
                             "{{ afi }}": {
                                 "afi": "{{ afi }}",
-                                "as_override": "{{ True }}"
-                            }
-                        }
-                    }
-                }
-            }
+                                "as_override": "{{ True }}",
+                            },
+                        },
+                    },
+                },
+            },
         },
         {
             "name": "neighbors.attribute_unchanged.as_path",
@@ -715,13 +671,13 @@ class Bgp_address_familyTemplate(NetworkTemplate):
                             "{{ afi }}": {
                                 "afi": "{{ afi }}",
                                 "attribute_unchanged": {
-                                    "as_path": "{{ True }}"
-                                }
-                            }
-                        }
-                    }
-                }
-            }
+                                    "as_path": "{{ True }}",
+                                },
+                            },
+                        },
+                    },
+                },
+            },
         },
         {
             "name": "neighbors.attribute_unchanged.med",
@@ -752,13 +708,13 @@ class Bgp_address_familyTemplate(NetworkTemplate):
                             "{{ afi }}": {
                                 "afi": "{{ afi }}",
                                 "attribute_unchanged": {
-                                    "med": "{{ True }}"
-                                }
-                            }
-                        }
-                    }
-                }
-            }
+                                    "med": "{{ True }}",
+                                },
+                            },
+                        },
+                    },
+                },
+            },
         },
         {
             "name": "neighbors.attribute_unchanged.next_hop",
@@ -789,13 +745,13 @@ class Bgp_address_familyTemplate(NetworkTemplate):
                             "{{ afi }}": {
                                 "afi": "{{ afi }}",
                                 "attribute_unchanged": {
-                                    "next_hop": "{{ True }}"
-                                }
-                            }
-                        }
-                    }
-                }
-            }
+                                    "next_hop": "{{ True }}",
+                                },
+                            },
+                        },
+                    },
+                },
+            },
         },
         {
             "name": "neighbors.capability_dynamic",
@@ -826,13 +782,13 @@ class Bgp_address_familyTemplate(NetworkTemplate):
                             "{{ afi }}": {
                                 "afi": "{{ afi }}",
                                 "capability": {
-                                    "dynamic": "{{ true }}"
-                                }
-                            }
-                        }
-                    }
-                }
-            }
+                                    "dynamic": "{{ true }}",
+                                },
+                            },
+                        },
+                    },
+                },
+            },
         },
         {
             "name": "neighbors.capability_orf",
@@ -864,13 +820,13 @@ class Bgp_address_familyTemplate(NetworkTemplate):
                             "{{ afi }}": {
                                 "afi": "{{ afi }}",
                                 "capability": {
-                                    "orf": "{{ orf }}"
-                                }
-                            }
-                        }
-                    }
-                }
-            }
+                                    "orf": "{{ orf }}",
+                                },
+                            },
+                        },
+                    },
+                },
+            },
         },
         {
             "name": "neighbors.default_originate",
@@ -901,12 +857,12 @@ class Bgp_address_familyTemplate(NetworkTemplate):
                         "address_family": {
                             "{{ afi }}": {
                                 "afi": "{{ afi }}",
-                                "default_originate": "{{ map }}"
-                            }
-                        }
-                    }
-                }
-            }
+                                "default_originate": "{{ map }}",
+                            },
+                        },
+                    },
+                },
+            },
         },
         {
             "name": "neighbors.distribute_list",
@@ -940,14 +896,14 @@ class Bgp_address_familyTemplate(NetworkTemplate):
                                 "distribute_list": [
                                     {
                                         "action": "{{ action }}",
-                                        "acl": "{{ list }}"
-                                    }
-                                ]
-                            }
-                        }
-                    }
-                }
-            }
+                                        "acl": "{{ list }}",
+                                    },
+                                ],
+                            },
+                        },
+                    },
+                },
+            },
         },
         {
             "name": "neighbors.prefix_list",
@@ -981,14 +937,14 @@ class Bgp_address_familyTemplate(NetworkTemplate):
                                 "prefix_list": [
                                     {
                                         "action": "{{ action }}",
-                                        "prefix_list": "{{ list }}"
-                                    }
-                                ]
-                            }
-                        }
-                    }
-                }
-            }
+                                        "prefix_list": "{{ list }}",
+                                    },
+                                ],
+                            },
+                        },
+                    },
+                },
+            },
         },
         {
             "name": "neighbors.filter_list",
@@ -1022,14 +978,14 @@ class Bgp_address_familyTemplate(NetworkTemplate):
                                 "filter_list": [
                                     {
                                         "action": "{{ action }}",
-                                        "path_list": "{{ list }}"
-                                    }
-                                ]
-                            }
-                        }
-                    }
-                }
-            }
+                                        "path_list": "{{ list }}",
+                                    },
+                                ],
+                            },
+                        },
+                    },
+                },
+            },
         },
         {
             "name": "neighbors.maximum_prefix",
@@ -1059,12 +1015,12 @@ class Bgp_address_familyTemplate(NetworkTemplate):
                         "address_family": {
                             "{{ afi }}": {
                                 "afi": "{{ afi }}",
-                                "maximum_prefix": "{{ num }}"
-                            }
-                        }
-                    }
-                }
-            }
+                                "maximum_prefix": "{{ num }}",
+                            },
+                        },
+                    },
+                },
+            },
         },
         {
             "name": "neighbors.nexthop_local",
@@ -1093,12 +1049,12 @@ class Bgp_address_familyTemplate(NetworkTemplate):
                         "address_family": {
                             "{{ afi }}": {
                                 "afi": "{{ afi }}",
-                                "nexthop_local": "{{ True }}"
-                            }
-                        }
-                    }
-                }
-            }
+                                "nexthop_local": "{{ True }}",
+                            },
+                        },
+                    },
+                },
+            },
         },
         {
             "name": "neighbors.nexthop_self",
@@ -1127,12 +1083,12 @@ class Bgp_address_familyTemplate(NetworkTemplate):
                         "address_family": {
                             "{{ afi }}": {
                                 "afi": "{{ afi }}",
-                                "nexthop_self": "{{ True }}"
-                            }
-                        }
-                    }
-                }
-            }
+                                "nexthop_self": "{{ True }}",
+                            },
+                        },
+                    },
+                },
+            },
         },
         {
             "name": "neighbors.peer_group",
@@ -1162,12 +1118,12 @@ class Bgp_address_familyTemplate(NetworkTemplate):
                         "address_family": {
                             "{{ afi }}": {
                                 "afi": "{{ afi }}",
-                                "peer_group": "{{ name }}"
-                            }
-                        }
-                    }
-                }
-            }
+                                "peer_group": "{{ name }}",
+                            },
+                        },
+                    },
+                },
+            },
         },
         {
             "name": "neighbors.remove_private_as",
@@ -1196,12 +1152,12 @@ class Bgp_address_familyTemplate(NetworkTemplate):
                         "address_family": {
                             "{{ afi }}": {
                                 "afi": "{{ afi }}",
-                                "remove_private_as": "{{ True }}"
-                            }
-                        }
-                    }
-                }
-            }
+                                "remove_private_as": "{{ True }}",
+                            },
+                        },
+                    },
+                },
+            },
         },
         {
             "name": "neighbors.route_map",
@@ -1235,14 +1191,14 @@ class Bgp_address_familyTemplate(NetworkTemplate):
                                 "route_map": [
                                     {
                                         "action": "{{ action }}",
-                                        "route_map": "{{ map }}"
-                                    }
-                                ]
-                            }
-                        }
-                    }
-                }
-            }
+                                        "route_map": "{{ map }}",
+                                    },
+                                ],
+                            },
+                        },
+                    },
+                },
+            },
         },
         {
             "name": "neighbors.route_reflector_client",
@@ -1271,12 +1227,12 @@ class Bgp_address_familyTemplate(NetworkTemplate):
                         "address_family": {
                             "{{ afi }}": {
                                 "afi": "{{ afi }}",
-                                "route_reflector_client": "{{ True }}"
-                            }
-                        }
-                    }
-                }
-            }
+                                "route_reflector_client": "{{ True }}",
+                            },
+                        },
+                    },
+                },
+            },
         },
         {
             "name": "neighbors.route_server_client",
@@ -1305,12 +1261,12 @@ class Bgp_address_familyTemplate(NetworkTemplate):
                         "address_family": {
                             "{{ afi }}": {
                                 "afi": "{{ afi }}",
-                                "route_server_client": "{{ True }}"
-                            }
-                        }
-                    }
-                }
-            }
+                                "route_server_client": "{{ True }}",
+                            },
+                        },
+                    },
+                },
+            },
         },
         {
             "name": "neighbors.soft_reconfiguration",
@@ -1340,12 +1296,12 @@ class Bgp_address_familyTemplate(NetworkTemplate):
                         "address_family": {
                             "{{ afi }}": {
                                 "afi": "{{ afi }}",
-                                "soft_reconfiguration": "{{ True }}"
-                            }
-                        }
-                    }
-                }
-            }
+                                "soft_reconfiguration": "{{ True }}",
+                            },
+                        },
+                    },
+                },
+            },
         },
         {
             "name": "neighbors.unsuppress_map",
@@ -1375,12 +1331,12 @@ class Bgp_address_familyTemplate(NetworkTemplate):
                         "address_family": {
                             "{{ afi }}": {
                                 "afi": "{{ afi }}",
-                                "unsuppress_map": "{{ map }}"
-                            }
-                        }
-                    }
-                }
-            }
+                                "unsuppress_map": "{{ map }}",
+                            },
+                        },
+                    },
+                },
+            },
         },
         {
             "name": "neighbors.weight",
@@ -1410,12 +1366,12 @@ class Bgp_address_familyTemplate(NetworkTemplate):
                         "address_family": {
                             "{{ afi }}": {
                                 "afi": "{{ afi }}",
-                                "weight": "{{ num }}"
-                            }
-                        }
-                    }
-                }
-            }
+                                "weight": "{{ num }}",
+                            },
+                        },
+                    },
+                },
+            },
         },
     ]
     # fmt: on
